==> 7.1.0.tar.gz: leenooks/src/Providers/LeenooksServiceProvider.php <==
<?php

namespace Leenooks\Providers;

use Leenooks\Http\Middleware\GuestUser;
use Illuminate\Routing\Router;
use Illuminate\Support\ServiceProvider;

/**
 * Class GuestUserServiceProvider.
 *
 * @package Acacha\User\Providers
 */
class LeenooksServiceProvider extends ServiceProvider
{
	private $_path = '';

	/**
	 * Bootstrap the application services.
	 *
	 * @param Router $router
	 */
	public function boot(Router $router)
	{
		$router->pushMiddlewareToGroup('web',GuestUser::class);

		$this->loadViewsFrom($this->_path.'/resources/themes/adminlte/views/', 'adminlte');
		$this->loadTranslationsFrom($this->_path.'/resources/themes/adminlte/lang/', 'adminlte_lang');

		$this->loadViewsFrom($this->_path.'/resources/themes/architect/views/', 'architect');

		// Enable a Collect::recursive() function
		\Illuminate\Support\Collection::macro('recursive', function () {
			return $this->map(function ($value) {

				if (is_array($value) || is_object($value)) {
					return collect($value)->recursive();
				}

				return $value;
			});
		});
	}

	/**
	 * Register the application services.
	 *
	 * @return void
	 */
	public function register()
	{
		if (! $this->_path) {
			$this->_path = realpath(__DIR__.'/../../');
		}
	}

	/**
	 * Views copy path.
	 *
	 * @return array
	 */
	public function views()
	{
		return [
			$this->_path.'/resources/views/auth' => resource_path('views/vendor/adminlte/auth'),
			$this->_path.'/resources/views/errors' => resource_path('views/vendor/adminlte/errors'),
			$this->_path.'/resources/views/layouts' => resource_path('views/vendor/adminlte/layouts'),
			$this->_path.'/resources/views/home.blade.php' => resource_path('views/vendor/adminlte/home.blade.php'),
			$this->_path.'/resources/views/welcome.blade.php' => resource_path('views/welcome.blade.php'),
		];
	}
}

==> 11.1.9.tar.gz: leenooks/src/Providers/LeenooksServiceProvider.php <==
<?php

namespace Leenooks\Providers;

use Illuminate\Foundation\AliasLoader;
use Illuminate\Support\Facades\Blade;
use Leenooks\Http\Middleware\GuestUser;
use Illuminate\Routing\Router;
use Illuminate\Support\Collection;
use Illuminate\Support\ServiceProvider;
use Leenooks\PageAssets;
use Leenooks\Traits\SingleOrFail;
use Orchestra\Support\Facades\Asset;

/**
 * Class GuestUserServiceProvider.
 *
 * @package Acacha\User\Providers
 */
class LeenooksServiceProvider extends ServiceProvider
{
	use SingleOrFail;

	private string $_path = '';

	/**
	 * Bootstrap the application services.
	 *
	 * @param Router $router
	 */
	public function boot(Router $router)
	{
		self::bootSingleOrfail();

		// Custom Aliases
		$loader = AliasLoader::getInstance();
		$loader->alias('PageAssets',PageAssets::class);

		$router->pushMiddlewareToGroup('web',GuestUser::class);

		$this->loadViewsFrom($this->_path.'/resources/themes/adminlte/views/', 'adminlte');
		$this->loadTranslationsFrom($this->_path.'/resources/themes/adminlte/lang/', 'adminlte_lang');

		$this->loadViewsFrom($this->_path.'/resources/themes/architect/views/', 'architect');

		$this->loadViewsFrom($this->_path.'/resources/themes/metronic/views/', 'metronic');

		//Blade::componentNamespace('Leenooks\\Components','leenooks');
		Blade::anonymousComponentPath($this->_path.'/resources/components', 'leenooks');

		// Add our page assets
		Blade::directive('pa',function($expression) {
			return sprintf('<?php PageAssets::asset(\'%s\') ?>',$expression);
		});

		// Enable a Collect::recursive() function
		Collection::macro('recursive', function () {
			return $this->map(function ($value) {
				if (is_array($value) || is_object($value)) {
					return collect($value)->recursive();
				}

				return $value;
			});
		});
	}

	/**
	 * Register the application services.
	 *
	 * @return void
	 */
	public function register()
	{
		if (! $this->_path) {
			$this->_path = realpath(__DIR__.'/../../');
		}
	}

	/**
	 * Views copy path.
	 *
	 * @return array
	 */
	public function views()
	{
		return [
			$this->_path.'/resources/views/auth' => resource_path('views/vendor/adminlte/auth'),
			$this->_path.'/resources/views/errors' => resource_path('views/vendor/adminlte/errors'),
			$this->_path.'/resources/views/layouts' => resource_path('views/vendor/adminlte/layouts'),
			$this->_path.'/resources/views/home.blade.php' => resource_path('views/vendor/adminlte/home.blade.php'),
			$this->_path.'/resources/views/welcome.blade.php' => resource_path('views/welcome.blade.php'),
		];
	}
}
